Name:		lout
Version:	3.40
Release:	%mkrel 8
Summary:	A document formatting system
License:	GPLv3+ and Public Domain
Group:		Publishing
Url:		http://lout.sourceforge.net/
Source0:	http://download.savannah.gnu.org/releases/lout/%{name}-%{version}.tar.gz
Patch0:		lout-3.38-fdr-fix-makefile.patch
BuildRequires:	ghostscript

%description
Lout is a high-level language for document formatting.  Lout reads a
high-level description of a document (similar in style to LaTeX) and can
produce a PostScript(TM) file for printing or produce plain text.
Lout supports the typesetting of documents which contain floating
figures, table, diagrams, rotated and scaled text or graphics, footnotes,
running headers, footers, an index, a table of contents and bibliography,
cross-references, mathematical equations and statistical graphs.  Lout can
be extended with definitions that should be easier to write than other
languages, since Lout is a high-level language.  Lout supports (with
hyphenation) a variety of languages:  Czech, Danish, Dutch, English,
Finnish, French, German, Norwegian, Russian, Slovenian, Spanish and
Swedish.

Install the lout package if you'd like to try the Lout document formatting
system.  Unless you're already a Lout expert, you'll probably want to also
install the lout-doc package, which contains the documentation for Lout.


%package doc
Summary:	The documentation for the Lout document formatting language
Group:		Documentation
BuildArch:	noarch

%description doc
The lout-doc package includes all of the documentation for the Lout
document formatting language.  The documentation includes manuals for
regular users and for experts, written in Lout and available as
PostScript(TM) files.  The documentation provides good examples for how to
write large documents with Lout.

If you're installing the lout package, you should install the lout-doc
package.


%prep
%setup -q 
%autopatch -p1

%build
%make COPTS="$RPM_OPT_FLAGS" \
      BINDIR=%{_bindir} \
      LOUTLIBDIR=%{_datadir}/%{name} \
      LOUTDOCDIR=%{_datadir}/%{name}/doc \
      MANDIR=%{_mandir}/man1 \
      LIBDIR=%{_datadir}/lout lout prg2lout

function render_docs {
    subdir=$1
    pdf_file=$2
    passes=$3

    curdir=$(pwd)
    pushd doc/$subdir

    # We need to set the PATH variable here, because lout eventually exec's
    #   prg2lout.  In order for lout to find the latter, we have to set the
    #   PATH.
    # We also need to tell lout where to find its files, since we haven't
    #   installed them in their final location under /usr/share/lout/ yet.
    PATH=$curdir lout \
       -I $curdir/include \
       -D $curdir/data \
       -F $curdir/font \
       -H $curdir/hyph \
       -C $curdir/maps \
       -r${passes} all > outfile.ps
    # Note that the above clobbers the prebuilt file outfile.ps that is
    # included in Lout's source tarball.
    ps2pdf outfile.ps ../${pdf_file}
    rm *.li *.ld outfile.ps
    popd
}

render_docs design design.pdf       3
render_docs expert expert-guide.pdf 4
render_docs slides slides.pdf       2
render_docs user   user-guide.pdf   6

%install
mkdir -p $RPM_BUILD_ROOT/%{_bindir}
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/%{name}/doc
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man1
make BINDIR=$RPM_BUILD_ROOT%{_bindir} \
     LOUTLIBDIR=$RPM_BUILD_ROOT%{_datadir}/%{name} \
     LOUTDOCDIR=$RPM_BUILD_ROOT%{_datadir}/%{name}/doc \
     MANDIR=$RPM_BUILD_ROOT%{_mandir}/man1 \
     install installman installdoc

# Looks like vim dump?
rm -rf $RPM_BUILD_ROOT%{_datadir}/%{name}/doc/user/.pie_intr.swp

%files
%doc blurb README maillist whatsnew notes_dsc
%{_bindir}/lout
%{_mandir}/man1/*
%{_bindir}/prg2lout
%{_datadir}/lout

%files doc
%doc doc/


%changelog
* Mon Feb 08 2016 umeabot <umeabot> 3.40-8.mga6
+ Revision: 947132
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.40-7.mga5
+ Revision: 750044
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.40-6.mga5
+ Revision: 681999
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.40-5.mga4
+ Revision: 529034
- Mageia 4 Mass Rebuild

* Mon Jul 01 2013 wally <wally> 3.40-4.mga4
+ Revision: 449398
- clean .spec (patch from Marja van Waes)

* Sat Jun 29 2013 wally <wally> 3.40-3.mga4
+ Revision: 448379
- add changes from Marja van Waes
- remove unneeded defines
- clean . spec a bit
- fix license

* Fri Jun 28 2013 kamil <kamil> 3.40-2.mga4
+ Revision: 448177
- really apply the part of removing the dead code

* Fri Jun 28 2013 kamil <kamil> 3.40-1.mga4
+ Revision: 448171
- upgrade patch by marja
- new version 3.40
- fix summary
- remove dead code
- adjust the GPL license to GPL-3.0+

* Sat Jan 12 2013 umeabot <umeabot> 3.39-3.mga3
+ Revision: 358966
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 3.39-2.mga3
+ Revision: 324595
- rebuild for Mga3 Beta1

* Mon Oct 22 2012 kamil <kamil> 3.39-1.mga3
+ Revision: 309292
- new version 3.39
- sync .spec with Fedora
- Remove old P0
- Add new P0 (from Fedora) fix-makefile.patch
- add ghostscript as BR (for book generation)

* Wed Oct 17 2012 malo <malo> 3.31-9.mga3
+ Revision: 307662
- fix/update RPM group
- doc package is noarch

* Tue Oct 09 2012 kamil <kamil> 3.31-8.mga3
+ Revision: 304008
- adapt a bit for Mageia
- imported package lout


* Fri Dec 10 2010 Oden Eriksson <oeriksson@mandriva.com> 3.31-7mdv2011.0
+ Revision: 620258
- the mass rebuild of 2010.0 packages

* Fri Sep 04 2009 Thierry Vignaud <tv@mandriva.org> 3.31-6mdv2010.0
+ Revision: 429869
- rebuild

* Mon Jul 28 2008 Thierry Vignaud <tv@mandriva.org> 3.31-5mdv2009.0
+ Revision: 251402
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 3.31-3mdv2008.1
+ Revision: 129460
- kill re-definition of %%buildroot on Pixel's request


* Wed May 24 2006 Pascal Terjan <pterjan@mandriva.com> 3.31-3mdk
- better fix (have data in /usr/share, not /usr/lib)

* Wed May 24 2006 Pascal Terjan <pterjan@mandriva.com> 3.31-2mdk
- fix build on x86_64

* Mon Dec 19 2005 Lenny Cartier <lenny@mandriva.com> 3.31-1mdk
- 3.31

* Mon Nov 15 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.30-1mdk
- 3.30

* Fri Jun 18 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.29-1mdk
- regenerate patch

* Sat Dec 13 2003 Per yvind Karlsen <peroyvind@linux-mandrake.com> 3.25-5mdk
- compile with optimizations on sparc
- spec cosmetics

* Wed Jul 23 2003 Per yvind Karlsen <peroyvind@sintrax.net> 3.25-4mdk
- rm -rf $RPM_BUILD_ROOT in %%install, not %%prep
- use %%make macro
- use %%makeinstall_std macro

